@@ -917,7 +917,7 @@ static int setup (wan_device_t* wandev, wandev_conf_t* conf)
 		break;
 		
 	case WANCONFIG_AFT:
-		DEBUG_EVENT("%s: Starting AFT Hardware Init.\n",
+		DEBUG_EVENT("%s: Starting AFT Legacy Hardware Init.\n",
 					card->devname);
 		err = wp_xilinx_init(card,conf);
 		break;
@@ -953,7 +953,7 @@ static int setup (wan_device_t* wandev, wandev_conf_t* conf)
 		break;
 
 	case WANCONFIG_AFT_SERIAL:
-		DEBUG_EVENT("%s: Starting AFT Serial (V32/RS232) Hardware Init.\n",
+		DEBUG_EVENT("%s: Starting AFT Serial (V35/RS232) Hardware Init.\n",
 					card->devname);
 		err = wp_aft_serial_init(card,conf);
 		break;
