@@ -9,6 +9,7 @@
 #               as published by the Free Software Foundation; either version
 #               2 of the License, or (at your option) any later version.
 # ----------------------------------------------------------------------------
+# Oct 16   2008  2.22	Jignesh Patel	Added Support for A600 
 # Oct 07   2008  2.21   Jignesh Patel 	Dahdi Soft-EC conf support for Analog & A101/2 cards
 # Sep 30   2008  2.20	Jignesh Patel   Configuration Support for Dahdi
 # Aug 20   2008  2.19	Jignesh Patel 	Suppor for HP TDM API for A10x added hp_a100
@@ -45,7 +46,7 @@ system('clear');
 print "\n########################################################################";
 print "\n#    		           Sangoma Wanpipe                              #";
 print "\n#        Dahdi/Zaptel/SMG/TDMAPI/BOOT Configuration Script             #";
-print "\n#                             v2.21                                    #";
+print "\n#                             v2.22                                    #";
 print "\n#                     Sangoma Technologies Inc.                        #";
 print "\n#                        Copyright(c) 2008.                            #";
 print "\n########################################################################\n\n";
@@ -2083,7 +2084,7 @@ sub config_t1e1{
 	foreach my $dev (@hwprobe) {
 		if ( $dev =~ /A(\d+)(.*):.*SLOT=(\d+).*BUS=(\d+).*CPU=(\w+).*PORT=(\w+).*/){
 
-		  	if ( ! ($1 eq '200' | $1 eq '400' | $1 eq '500') ){
+		  	if ( ! ($1 eq '200' | $1 eq '400' | $1 eq '500' | $1 eq '600') ){
 				#do not count analog devices
 				$num_digital_devices_total++;
 			}
@@ -2756,7 +2757,7 @@ sub config_analog{
 	}
 	$first_cfg=0;
 	print "------------------------------------\n";
-	print "Configuring analog cards [A200/A400]\n";
+	print "Configuring analog cards [A200/A400/A600]\n";
 	print "------------------------------------\n";
 
 	my $skip_card=$FALSE;
@@ -2766,7 +2767,9 @@ sub config_analog{
 	}
 	foreach my $dev (@hwprobe) {
 		
-		if ( $dev =~ /(\d+).(\w+\w+).*SLOT=(\d+).*BUS=(\d+).*CPU=(\w+).*PORT=(\w+).*HWEC=(\d+)/){
+		
+	        if ( $dev =~ /(\d+).(\w+\w+).*SLOT=(\d+).*BUS=(\d+).*.*HWEC=(\d+)/){
+
 			$skip_card=$FALSE;
 			my $card = eval {new Card(); } or die ($@);
 			$card->current_dir($current_dir);
@@ -2775,8 +2778,9 @@ sub config_analog{
 			$card->card_model($1);
 			$card->pci_slot($3);
 			$card->pci_bus($4);
-			$card->fe_cpu($5);
-			my $hwec=$7;
+			#fe_cpu is not used for analog cards
+			#$card->fe_cpu($5);
+			my $hwec=$5;
 			if($dahdi_installed == $TRUE) {
 					$card->dahdi_conf('YES');
 					$card->dahdi_echo($dahdi_echo)
@@ -2788,7 +2792,7 @@ sub config_analog{
 				$card->hwec_mode('YES');
 				
 			}
-			if ($card->card_model eq '200' | $card->card_model eq '400'){
+			if ($card->card_model eq '200' | $card->card_model eq '400' | $card->card_model eq '600'){
 				$num_analog_devices_total++;
 				if($silent==$FALSE) {
 					system('clear');
